@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from grafeas.grafeas_v1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -145,11 +156,11 @@ class GrafeasAsyncClient:
 
     async def get_occurrence(
         self,
-        request: Union[grafeas.GetOccurrenceRequest, dict] = None,
+        request: Optional[Union[grafeas.GetOccurrenceRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Occurrence:
         r"""Gets the specified occurrence.
@@ -181,7 +192,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.GetOccurrenceRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.GetOccurrenceRequest, dict]]):
                 The request object. Request to get an occurrence.
             name (:class:`str`):
                 The name of the occurrence in the form of
@@ -256,12 +267,12 @@ class GrafeasAsyncClient:
 
     async def list_occurrences(
         self,
-        request: Union[grafeas.ListOccurrencesRequest, dict] = None,
+        request: Optional[Union[grafeas.ListOccurrencesRequest, dict]] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOccurrencesAsyncPager:
         r"""Lists occurrences for the specified project.
@@ -294,7 +305,7 @@ class GrafeasAsyncClient:
                     print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.ListOccurrencesRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.ListOccurrencesRequest, dict]]):
                 The request object. Request to list occurrences.
             parent (:class:`str`):
                 The name of the project to list occurrences for in the
@@ -387,11 +398,11 @@ class GrafeasAsyncClient:
 
     async def delete_occurrence(
         self,
-        request: Union[grafeas.DeleteOccurrenceRequest, dict] = None,
+        request: Optional[Union[grafeas.DeleteOccurrenceRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified occurrence. For example, use
@@ -422,7 +433,7 @@ class GrafeasAsyncClient:
                 await client.delete_occurrence(request=request)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.DeleteOccurrenceRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.DeleteOccurrenceRequest, dict]]):
                 The request object. Request to delete an occurrence.
             name (:class:`str`):
                 The name of the occurrence in the form of
@@ -488,12 +499,12 @@ class GrafeasAsyncClient:
 
     async def create_occurrence(
         self,
-        request: Union[grafeas.CreateOccurrenceRequest, dict] = None,
+        request: Optional[Union[grafeas.CreateOccurrenceRequest, dict]] = None,
         *,
-        parent: str = None,
-        occurrence: grafeas.Occurrence = None,
+        parent: Optional[str] = None,
+        occurrence: Optional[grafeas.Occurrence] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Occurrence:
         r"""Creates a new occurrence.
@@ -525,7 +536,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.CreateOccurrenceRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.CreateOccurrenceRequest, dict]]):
                 The request object. Request to create a new occurrence.
             parent (:class:`str`):
                 The name of the project in the form of
@@ -598,12 +609,12 @@ class GrafeasAsyncClient:
 
     async def batch_create_occurrences(
         self,
-        request: Union[grafeas.BatchCreateOccurrencesRequest, dict] = None,
+        request: Optional[Union[grafeas.BatchCreateOccurrencesRequest, dict]] = None,
         *,
-        parent: str = None,
-        occurrences: Sequence[grafeas.Occurrence] = None,
+        parent: Optional[str] = None,
+        occurrences: Optional[MutableSequence[grafeas.Occurrence]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.BatchCreateOccurrencesResponse:
         r"""Creates new occurrences in batch.
@@ -635,7 +646,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.BatchCreateOccurrencesRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.BatchCreateOccurrencesRequest, dict]]):
                 The request object. Request to create occurrences in
                 batch.
             parent (:class:`str`):
@@ -646,7 +657,7 @@ class GrafeasAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            occurrences (:class:`Sequence[grafeas.grafeas_v1.types.Occurrence]`):
+            occurrences (:class:`MutableSequence[grafeas.grafeas_v1.types.Occurrence]`):
                 The occurrences to create. Max
                 allowed length is 1000.
 
@@ -711,13 +722,13 @@ class GrafeasAsyncClient:
 
     async def update_occurrence(
         self,
-        request: Union[grafeas.UpdateOccurrenceRequest, dict] = None,
+        request: Optional[Union[grafeas.UpdateOccurrenceRequest, dict]] = None,
         *,
-        name: str = None,
-        occurrence: grafeas.Occurrence = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        name: Optional[str] = None,
+        occurrence: Optional[grafeas.Occurrence] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Occurrence:
         r"""Updates the specified occurrence.
@@ -749,7 +760,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.UpdateOccurrenceRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.UpdateOccurrenceRequest, dict]]):
                 The request object. Request to update an occurrence.
             name (:class:`str`):
                 The name of the occurrence in the form of
@@ -828,11 +839,11 @@ class GrafeasAsyncClient:
 
     async def get_occurrence_note(
         self,
-        request: Union[grafeas.GetOccurrenceNoteRequest, dict] = None,
+        request: Optional[Union[grafeas.GetOccurrenceNoteRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
         r"""Gets the note attached to the specified occurrence.
@@ -866,7 +877,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.GetOccurrenceNoteRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.GetOccurrenceNoteRequest, dict]]):
                 The request object. Request to get the note to which the
                 specified occurrence is attached.
             name (:class:`str`):
@@ -942,11 +953,11 @@ class GrafeasAsyncClient:
 
     async def get_note(
         self,
-        request: Union[grafeas.GetNoteRequest, dict] = None,
+        request: Optional[Union[grafeas.GetNoteRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
         r"""Gets the specified note.
@@ -978,7 +989,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.GetNoteRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.GetNoteRequest, dict]]):
                 The request object. Request to get a note.
             name (:class:`str`):
                 The name of the note in the form of
@@ -1053,12 +1064,12 @@ class GrafeasAsyncClient:
 
     async def list_notes(
         self,
-        request: Union[grafeas.ListNotesRequest, dict] = None,
+        request: Optional[Union[grafeas.ListNotesRequest, dict]] = None,
         *,
-        parent: str = None,
-        filter: str = None,
+        parent: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListNotesAsyncPager:
         r"""Lists notes for the specified project.
@@ -1091,7 +1102,7 @@ class GrafeasAsyncClient:
                     print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.ListNotesRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.ListNotesRequest, dict]]):
                 The request object. Request to list notes.
             parent (:class:`str`):
                 The name of the project to list notes for in the form of
@@ -1184,11 +1195,11 @@ class GrafeasAsyncClient:
 
     async def delete_note(
         self,
-        request: Union[grafeas.DeleteNoteRequest, dict] = None,
+        request: Optional[Union[grafeas.DeleteNoteRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified note.
@@ -1217,7 +1228,7 @@ class GrafeasAsyncClient:
                 await client.delete_note(request=request)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.DeleteNoteRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.DeleteNoteRequest, dict]]):
                 The request object. Request to delete a note.
             name (:class:`str`):
                 The name of the note in the form of
@@ -1283,13 +1294,13 @@ class GrafeasAsyncClient:
 
     async def create_note(
         self,
-        request: Union[grafeas.CreateNoteRequest, dict] = None,
+        request: Optional[Union[grafeas.CreateNoteRequest, dict]] = None,
         *,
-        parent: str = None,
-        note_id: str = None,
-        note: grafeas.Note = None,
+        parent: Optional[str] = None,
+        note_id: Optional[str] = None,
+        note: Optional[grafeas.Note] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
         r"""Creates a new note.
@@ -1322,7 +1333,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.CreateNoteRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.CreateNoteRequest, dict]]):
                 The request object. Request to create a new note.
             parent (:class:`str`):
                 The name of the project in the form of
@@ -1402,12 +1413,12 @@ class GrafeasAsyncClient:
 
     async def batch_create_notes(
         self,
-        request: Union[grafeas.BatchCreateNotesRequest, dict] = None,
+        request: Optional[Union[grafeas.BatchCreateNotesRequest, dict]] = None,
         *,
-        parent: str = None,
-        notes: Mapping[str, grafeas.Note] = None,
+        parent: Optional[str] = None,
+        notes: Optional[MutableMapping[str, grafeas.Note]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.BatchCreateNotesResponse:
         r"""Creates new notes in batch.
@@ -1439,7 +1450,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.BatchCreateNotesRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.BatchCreateNotesRequest, dict]]):
                 The request object. Request to create notes in batch.
             parent (:class:`str`):
                 The name of the project in the form of
@@ -1449,7 +1460,7 @@ class GrafeasAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            notes (:class:`Mapping[str, grafeas.grafeas_v1.types.Note]`):
+            notes (:class:`MutableMapping[str, grafeas.grafeas_v1.types.Note]`):
                 The notes to create. Max allowed
                 length is 1000.
 
@@ -1513,13 +1524,13 @@ class GrafeasAsyncClient:
 
     async def update_note(
         self,
-        request: Union[grafeas.UpdateNoteRequest, dict] = None,
+        request: Optional[Union[grafeas.UpdateNoteRequest, dict]] = None,
         *,
-        name: str = None,
-        note: grafeas.Note = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        name: Optional[str] = None,
+        note: Optional[grafeas.Note] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
         r"""Updates the specified note.
@@ -1551,7 +1562,7 @@ class GrafeasAsyncClient:
                 print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.UpdateNoteRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.UpdateNoteRequest, dict]]):
                 The request object. Request to update a note.
             name (:class:`str`):
                 The name of the note in the form of
@@ -1630,12 +1641,12 @@ class GrafeasAsyncClient:
 
     async def list_note_occurrences(
         self,
-        request: Union[grafeas.ListNoteOccurrencesRequest, dict] = None,
+        request: Optional[Union[grafeas.ListNoteOccurrencesRequest, dict]] = None,
         *,
-        name: str = None,
-        filter: str = None,
+        name: Optional[str] = None,
+        filter: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListNoteOccurrencesAsyncPager:
         r"""Lists occurrences referencing the specified note.
@@ -1671,7 +1682,7 @@ class GrafeasAsyncClient:
                     print(response)
 
         Args:
-            request (Union[grafeas.grafeas_v1.types.ListNoteOccurrencesRequest, dict]):
+            request (Optional[Union[grafeas.grafeas_v1.types.ListNoteOccurrencesRequest, dict]]):
                 The request object. Request to list occurrences for a
                 note.
             name (:class:`str`):
@@ -1771,14 +1782,9 @@ class GrafeasAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "grafeas",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GrafeasAsyncClient",)
