@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -42,13 +44,13 @@ class VulnerabilityNote(proto.Message):
         severity (grafeas.grafeas_v1.types.Severity):
             The note provider assigned severity of this
             vulnerability.
-        details (Sequence[grafeas.grafeas_v1.types.VulnerabilityNote.Detail]):
+        details (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityNote.Detail]):
             Details of all known distros and packages
             affected by this vulnerability.
         cvss_v3 (grafeas.grafeas_v1.types.CVSSv3):
             The full description of the CVSSv3 for this
             vulnerability.
-        windows_details (Sequence[grafeas.grafeas_v1.types.VulnerabilityNote.WindowsDetail]):
+        windows_details (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityNote.WindowsDetail]):
             Windows details get their own format because
             the information format and model don't match a
             normal detail. Specifically Windows updates are
@@ -133,63 +135,63 @@ class VulnerabilityNote(proto.Message):
                 The name of the vendor of the product.
         """
 
-        severity_name = proto.Field(
+        severity_name: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        description = proto.Field(
+        description: str = proto.Field(
             proto.STRING,
             number=2,
         )
-        package_type = proto.Field(
+        package_type: str = proto.Field(
             proto.STRING,
             number=3,
         )
-        affected_cpe_uri = proto.Field(
+        affected_cpe_uri: str = proto.Field(
             proto.STRING,
             number=4,
         )
-        affected_package = proto.Field(
+        affected_package: str = proto.Field(
             proto.STRING,
             number=5,
         )
-        affected_version_start = proto.Field(
+        affected_version_start: package.Version = proto.Field(
             proto.MESSAGE,
             number=6,
             message=package.Version,
         )
-        affected_version_end = proto.Field(
+        affected_version_end: package.Version = proto.Field(
             proto.MESSAGE,
             number=7,
             message=package.Version,
         )
-        fixed_cpe_uri = proto.Field(
+        fixed_cpe_uri: str = proto.Field(
             proto.STRING,
             number=8,
         )
-        fixed_package = proto.Field(
+        fixed_package: str = proto.Field(
             proto.STRING,
             number=9,
         )
-        fixed_version = proto.Field(
+        fixed_version: package.Version = proto.Field(
             proto.MESSAGE,
             number=10,
             message=package.Version,
         )
-        is_obsolete = proto.Field(
+        is_obsolete: bool = proto.Field(
             proto.BOOL,
             number=11,
         )
-        source_update_time = proto.Field(
+        source_update_time: timestamp_pb2.Timestamp = proto.Field(
             proto.MESSAGE,
             number=12,
             message=timestamp_pb2.Timestamp,
         )
-        source = proto.Field(
+        source: str = proto.Field(
             proto.STRING,
             number=13,
         )
-        vendor = proto.Field(
+        vendor: str = proto.Field(
             proto.STRING,
             number=14,
         )
@@ -206,7 +208,7 @@ class VulnerabilityNote(proto.Message):
                 Required. The name of this vulnerability.
             description (str):
                 The description of this vulnerability.
-            fixing_kbs (Sequence[grafeas.grafeas_v1.types.VulnerabilityNote.WindowsDetail.KnowledgeBase]):
+            fixing_kbs (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityNote.WindowsDetail.KnowledgeBase]):
                 Required. The names of the KBs which have
                 hotfixes to mitigate this vulnerability. Note
                 that there may be multiple hotfixes (and thus
@@ -227,63 +229,65 @@ class VulnerabilityNote(proto.Message):
                     (https://www.catalog.update.microsoft.com/).
             """
 
-            name = proto.Field(
+            name: str = proto.Field(
                 proto.STRING,
                 number=1,
             )
-            url = proto.Field(
+            url: str = proto.Field(
                 proto.STRING,
                 number=2,
             )
 
-        cpe_uri = proto.Field(
+        cpe_uri: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        name = proto.Field(
+        name: str = proto.Field(
             proto.STRING,
             number=2,
         )
-        description = proto.Field(
+        description: str = proto.Field(
             proto.STRING,
             number=3,
         )
-        fixing_kbs = proto.RepeatedField(
+        fixing_kbs: MutableSequence[
+            "VulnerabilityNote.WindowsDetail.KnowledgeBase"
+        ] = proto.RepeatedField(
             proto.MESSAGE,
             number=4,
             message="VulnerabilityNote.WindowsDetail.KnowledgeBase",
         )
 
-    cvss_score = proto.Field(
+    cvss_score: float = proto.Field(
         proto.FLOAT,
         number=1,
     )
-    severity = proto.Field(
+    severity: g_severity.Severity = proto.Field(
         proto.ENUM,
         number=2,
         enum=g_severity.Severity,
     )
-    details = proto.RepeatedField(
+    details: MutableSequence[Detail] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message=Detail,
     )
-    cvss_v3 = proto.Field(
+    cvss_v3: cvss.CVSSv3 = proto.Field(
         proto.MESSAGE,
         number=4,
         message=cvss.CVSSv3,
     )
-    windows_details = proto.RepeatedField(
+    windows_details: MutableSequence[WindowsDetail] = proto.RepeatedField(
         proto.MESSAGE,
         number=5,
         message=WindowsDetail,
     )
-    source_update_time = proto.Field(
+    source_update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=6,
         message=timestamp_pb2.Timestamp,
     )
-    cvss_version = proto.Field(
+    cvss_version: cvss.CVSSVersion = proto.Field(
         proto.ENUM,
         number=7,
         enum=cvss.CVSSVersion,
@@ -308,7 +312,7 @@ class VulnerabilityOccurrence(proto.Message):
             indicates high severity.
         cvssv3 (grafeas.grafeas_v1.types.CVSS):
             The cvss v3 score for the vulnerability.
-        package_issue (Sequence[grafeas.grafeas_v1.types.VulnerabilityOccurrence.PackageIssue]):
+        package_issue (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityOccurrence.PackageIssue]):
             Required. The set of affected locations and
             their fixes (if available) within the associated
             resource.
@@ -318,7 +322,7 @@ class VulnerabilityOccurrence(proto.Message):
         long_description (str):
             Output only. A detailed description of this
             vulnerability.
-        related_urls (Sequence[grafeas.grafeas_v1.types.RelatedUrl]):
+        related_urls (MutableSequence[grafeas.grafeas_v1.types.RelatedUrl]):
             Output only. URLs related to this
             vulnerability.
         effective_severity (grafeas.grafeas_v1.types.Severity):
@@ -382,101 +386,101 @@ class VulnerabilityOccurrence(proto.Message):
                 severity for this vulnerability when that is
                 available and note provider assigned severity
                 when it is not available.
-            file_location (Sequence[grafeas.grafeas_v1.types.FileLocation]):
+            file_location (MutableSequence[grafeas.grafeas_v1.types.FileLocation]):
                 The location at which this package was found.
         """
 
-        affected_cpe_uri = proto.Field(
+        affected_cpe_uri: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        affected_package = proto.Field(
+        affected_package: str = proto.Field(
             proto.STRING,
             number=2,
         )
-        affected_version = proto.Field(
+        affected_version: package.Version = proto.Field(
             proto.MESSAGE,
             number=3,
             message=package.Version,
         )
-        fixed_cpe_uri = proto.Field(
+        fixed_cpe_uri: str = proto.Field(
             proto.STRING,
             number=4,
         )
-        fixed_package = proto.Field(
+        fixed_package: str = proto.Field(
             proto.STRING,
             number=5,
         )
-        fixed_version = proto.Field(
+        fixed_version: package.Version = proto.Field(
             proto.MESSAGE,
             number=6,
             message=package.Version,
         )
-        fix_available = proto.Field(
+        fix_available: bool = proto.Field(
             proto.BOOL,
             number=7,
         )
-        package_type = proto.Field(
+        package_type: str = proto.Field(
             proto.STRING,
             number=8,
         )
-        effective_severity = proto.Field(
+        effective_severity: g_severity.Severity = proto.Field(
             proto.ENUM,
             number=9,
             enum=g_severity.Severity,
         )
-        file_location = proto.RepeatedField(
+        file_location: MutableSequence[common.FileLocation] = proto.RepeatedField(
             proto.MESSAGE,
             number=10,
             message=common.FileLocation,
         )
 
-    type_ = proto.Field(
+    type_: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    severity = proto.Field(
+    severity: g_severity.Severity = proto.Field(
         proto.ENUM,
         number=2,
         enum=g_severity.Severity,
     )
-    cvss_score = proto.Field(
+    cvss_score: float = proto.Field(
         proto.FLOAT,
         number=3,
     )
-    cvssv3 = proto.Field(
+    cvssv3: cvss.CVSS = proto.Field(
         proto.MESSAGE,
         number=10,
         message=cvss.CVSS,
     )
-    package_issue = proto.RepeatedField(
+    package_issue: MutableSequence[PackageIssue] = proto.RepeatedField(
         proto.MESSAGE,
         number=4,
         message=PackageIssue,
     )
-    short_description = proto.Field(
+    short_description: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    long_description = proto.Field(
+    long_description: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    related_urls = proto.RepeatedField(
+    related_urls: MutableSequence[common.RelatedUrl] = proto.RepeatedField(
         proto.MESSAGE,
         number=7,
         message=common.RelatedUrl,
     )
-    effective_severity = proto.Field(
+    effective_severity: g_severity.Severity = proto.Field(
         proto.ENUM,
         number=8,
         enum=g_severity.Severity,
     )
-    fix_available = proto.Field(
+    fix_available: bool = proto.Field(
         proto.BOOL,
         number=9,
     )
-    cvss_version = proto.Field(
+    cvss_version: cvss.CVSSVersion = proto.Field(
         proto.ENUM,
         number=11,
         enum=cvss.CVSSVersion,
